@@ -12,21 +12,25 @@ par(mar=c(5,4,4,2))
 ## ------------------------------------------------------------------------
 library(vcfR)
 data(vcfR_example)
+vcf
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=TRUE, tidy=TRUE-----------------------------------------------
 strwrap(vcf@meta[1:7])
 
-## ---- echo=FALSE---------------------------------------------------------
-vcf@fix[1:6, 1:7]
+## ------------------------------------------------------------------------
+queryMETA(vcf)
 
 ## ------------------------------------------------------------------------
-strwrap(grep('DP', vcf@meta, value = TRUE))
+queryMETA(vcf, element = 'DP')
+
+## ------------------------------------------------------------------------
+queryMETA(vcf, element = 'FORMAT=<ID=DP')
 
 ## ---- echo=TRUE----------------------------------------------------------
-unlist(strsplit(as.character(vcf@fix[1, 8]), split=";"))
+head(getFIX(vcf))
 
-## ---- echo=FALSE---------------------------------------------------------
-vcf@gt[1:6, 1:8]
+## ---- echo=TRUE, tidy=TRUE-----------------------------------------------
+vcf@gt[1:6, 1:4]
 
 ## ------------------------------------------------------------------------
 head(vcf)
